@@ -1266,11 +1266,11 @@ void copyparams(objinstptr destinst, objinstptr sourceinst)
 
    for (cops = psource; cops != NULL; cops = cops->next) {
       if ((ips = match_instance_param(destinst, cops->key)) == NULL) {
-	 if ((cops->type != XC_EXPR) || (destinst == sourceinst)) {
+//	 if ((cops->type != XC_EXPR) || (destinst == sourceinst)) {
             newops = copyparameter(cops);
 	    newops->next = destinst->params;
 	    destinst->params = newops;
-	 }
+//	 }
       }
       else if ((cops->type == XC_EXPR) && (ips->type != XC_EXPR))
 	 free_instance_param(destinst, ips);
