@@ -616,6 +616,7 @@ typedef struct _eparam {
    char *	key;	    /* name of the parameter */
    union {
       int	pointno;    /* point number in point array, for polygons */
+      short	pathpt[2];  /* element number and point number, for paths */
       char	*refkey;    /* parameter reference key, for instances */
    } pdata;
    eparamptr	next;	    /* next parameter in linked list */
@@ -1404,7 +1405,7 @@ typedef struct {
 typedef struct _Technology *TechPtr;
 
 typedef struct _Technology {
-   char		flags;		/* Flags for library page (changed, read-only) */
+   u_char	flags;		/* Flags for library page (changed, read-only) */
    char		*technology;	/* Namespace name (without the "::") */
    char		*filename;	/* Library file associated with technology */
    TechPtr 	next;		/* Linked list */
